@@ -4,13 +4,13 @@
 /**
  * XML RSS parser
  *
- * PHP version 4
+ * PHP version 5
  *
  * @category XML
  * @package  XML_RSS
  * @author   Martin Jansen <mj@php.net>
  * @license  PHP License http://php.net/license
- * @version  SVN: $Id: RSS.php 310689 2011-05-01 17:54:48Z kguest $
+ * @version  Release: 1.1.0
  * @link     http://pear.php.net/package/XML_RSS
  */
 
@@ -174,12 +174,12 @@ class XML_RSS extends XML_Parser
      * @return void
      * @access public
      */
-    function XML_RSS($handle = '', $srcenc = null, $tgtenc = null)
+    function __construct($handle = '', $srcenc = null, $tgtenc = null)
     {
         if ($srcenc === null && $tgtenc === null) {
-            $this->XML_Parser();
+            parent::__construct();
         } else {
-            $this->XML_Parser($srcenc, 'event', $tgtenc);
+            parent::__construct($srcenc, 'event', $tgtenc);
         }
 
         $this->setInput($handle);
@@ -202,7 +202,7 @@ class XML_RSS extends XML_Parser
      * @return void
      * @access private
      */
-    function startHandler($parser, $element, $attribs)
+    function startHandler($parser, $element, &$attribs)
     {
         if (substr($element, 0, 4) == "RSS:") {
             $element = substr($element, 4);
@@ -261,17 +261,17 @@ class XML_RSS extends XML_Parser
 
         if ($element == 'ITEM') {
             $this->items[] = $this->item;
-            $this->item = '';
+            $this->item = array();
         }
 
         if ($element == 'IMAGE') {
             $this->images[] = $this->image;
-            $this->image = '';
+            $this->image = array();
         }
 
         if ($element == 'TEXTINPUT') {
             $this->textinputs = $this->textinput;
-            $this->textinput = '';
+            $this->textinput = array();
         }
 
         if ($element == 'ENCLOSURE') {
